# Autogenerated by Astropy's setup.py on 2019-10-27 22:08:20 UTC
import datetime

version = "3.2.3"
githash = "b70ce8748b03f60a14c2fe9fdd17b88aa89851e5"


major = 3
minor = 2
bugfix = 3

version_info = (major, minor, bugfix)

release = True
timestamp = datetime.datetime(2019, 10, 27, 22, 8, 20)
debug = False

astropy_helpers_version = "3.2.2"
